@@ -5,6 +5,7 @@ zqy's utility functions
 from __future__ import unicode_literals
 
 from .collect_env_info import *  # noqa
+from .cpr import *  # noqa
 from .debug import *  # noqa
 from .dicom import *  # noqa
 from .dict import *  # noqa
@@ -13,10 +14,11 @@ from .plot import *  # noqa
 from .point import *  # noqa
 from .print import *  # noqa
 from .registry import *  # noqa
+from .vtk import *  # noqa
 
 # from .virtual_data import *  # noqa
 
-__version__ = "0.1.11"
+__version__ = "0.2.0"
 __short_description__ = "zqy's utility functions."
 __license__ = "MIT"
 __author__ = "qianyizhang"
